@@ -29,7 +29,7 @@ from ast import literal_eval
 
 import wx
 
-VERSION = "1.0.3"
+VERSION = "1.1"
 
 
 class DefaultConfig(object):
@@ -51,6 +51,17 @@ class DefaultConfig(object):
         standardpaths = wx.StandardPaths.Get()
         self.work_path = standardpaths.GetDocumentsDir()
 
+        # UI language
+        # -----------
+
+        self.ui_language = "'en'"  # 'system' for system locale 
+
+        # Spell checking lamguage
+        # -----------------------
+
+        self.check_spelling = "False"
+        self.spell_lang = "'en_US'"
+
         # Default filetypes
         # -----------------
 
@@ -98,6 +109,7 @@ class DefaultConfig(object):
         # Fonts
 
         self.font = repr(wx.SYS_DEFAULT_GUI_FONT)
+        self.font_save_enabled = "False"
 
         # Default cell font size
 
