@@ -54,6 +54,8 @@ from src.gui._menubars import MainMenu
 from src.gui._toolbars import MainToolbar, MacroToolbar, FindToolbar
 from src.gui._toolbars import WidgetToolbar, AttributesToolbar
 from src.gui._widgets import EntryLineToolbarPanel, StatusBar
+from src.gui._widgets import TableChoiceListCtrl
+from src.gui._dialogs import DependencyDialog
 
 from src.lib.clipboard import Clipboard
 from src.lib.filetypes import get_filetypes2wildcards
@@ -144,6 +146,9 @@ class MainWindow(wx.Frame, EventMixin):
         # Main grid
         self.grid = Grid(self, -1, S=S, dimensions=dimensions)
 
+        # TableChoiceListCtrl
+        self.table_list_panel = TableChoiceListCtrl(self, self.grid)
+
         # Clipboard
         self.clipboard = Clipboard()
 
@@ -192,6 +197,7 @@ class MainWindow(wx.Frame, EventMixin):
             (self.find_toolbar, "find_toolbar", _("Find toolbar")),
             (self.widget_toolbar, "widget_toolbar", _("Widget toolbar")),
             (self.entry_line_panel, "entry_line_panel", _("Entry line")),
+            (self.table_list_panel, "table_list_panel", _("Table list")),
         ]
 
         for toolbar, pane_name, toggle_label in toggles:
@@ -239,6 +245,10 @@ class MainWindow(wx.Frame, EventMixin):
                           Gripper(False).CenterPane().Top().Row(2).
                           BestSize(400, 30).PaneBorder(False))
 
+        self._mgr.AddPane(self.table_list_panel, aui.AuiPaneInfo().
+                          Name("table_list_panel").Caption(_("Table")).
+                          CenterPane().Left().BestSize(50, 300))
+
         # Load perspective from config
         window_layout = config["window_layout"]
 
@@ -285,6 +295,7 @@ class MainWindow(wx.Frame, EventMixin):
         self.Bind(self.EVT_CMD_SAFE_MODE_EXIT, handlers.OnSafeModeExit)
         self.Bind(wx.EVT_CLOSE, handlers.OnClose)
         self.Bind(self.EVT_CMD_CLOSE, handlers.OnClose)
+        self.Bind(self.EVT_SPELL_CHECK, handlers.OnSpellCheckToggle)
 
         # Preferences events
 
@@ -305,6 +316,8 @@ class MainWindow(wx.Frame, EventMixin):
                   handlers.OnFindToolbarToggle)
         self.Bind(self.EVT_CMD_ENTRYLINE_TOGGLE,
                   handlers.OnEntryLineToggle)
+        self.Bind(self.EVT_CMD_TABLELIST_TOGGLE,
+                  handlers.OnTableListToggle)
         self.Bind(aui.EVT_AUI_PANE_CLOSE, handlers.OnPaneClose)
 
         # File events
@@ -350,6 +363,7 @@ class MainWindow(wx.Frame, EventMixin):
         self.Bind(self.EVT_CMD_TUTORIAL, handlers.OnTutorial)
         self.Bind(self.EVT_CMD_FAQ, handlers.OnFaq)
         self.Bind(self.EVT_CMD_PYTHON_TURORIAL, handlers.OnPythonTutorial)
+        self.Bind(self.EVT_CMD_DEPENDENCIES, handlers.OnDependencies)
         self.Bind(self.EVT_CMD_ABOUT, handlers.OnAbout)
 
         self.Bind(self.EVT_CMD_MACROLIST, handlers.OnMacroList)
@@ -531,6 +545,18 @@ class MainWindowEventHandlers(EventMixin):
             dummyfile.close()
             os.chmod(pyspreadrc_path, 0600)
 
+    def OnSpellCheckToggle(self, event):
+        """Spell checking toggle event handler"""
+
+        spelltoolid = self.main_window.main_toolbar.label2id["CheckSpelling"]
+        self.main_window.main_toolbar.ToggleTool(spelltoolid,
+                                                 not config["check_spelling"])
+
+        config["check_spelling"] = repr(not config["check_spelling"])
+
+        self.main_window.grid.grid_renderer.cell_cache.clear()
+        self.main_window.grid.ForceRefresh()
+
     # Preferences events
 
     def OnPreferences(self, event):
@@ -545,6 +571,9 @@ class MainWindowEventHandlers(EventMixin):
                 else:
                     config[key] = ast.literal_eval(preferences[key])
 
+        self.main_window.grid.grid_renderer.cell_cache.clear()
+        self.main_window.grid.ForceRefresh()
+
     def OnNewGpgKey(self, event):
         """New GPG key event handler.
 
@@ -645,6 +674,16 @@ class MainWindowEventHandlers(EventMixin):
 
         event.Skip()
 
+    def OnTableListToggle(self, event):
+        """Table list toggle event handler"""
+
+        table_list_panel_info = \
+            self.main_window._mgr.GetPane("table_list_panel")
+
+        self._toggle_pane(table_list_panel_info)
+
+        event.Skip()
+
     def OnPaneClose(self, event):
         """Pane close toggle event handler (via close button)"""
 
@@ -755,7 +794,8 @@ class MainWindowEventHandlers(EventMixin):
                 post_command_event(self.main_window, self.main_window.SaveMsg)
 
         # Get filepath from user
-        f2w = get_filetypes2wildcards(["pys", "pysu", "xls", "xlsx", "all"])
+        f2w = get_filetypes2wildcards(
+            ["pys", "pysu", "xls", "xlsx", "ods", "all"])
         filetypes = f2w.keys()
         wildcards = f2w.values()
         wildcard = "|".join(wildcards)
@@ -1438,11 +1478,16 @@ class MainWindowEventHandlers(EventMixin):
     def OnPythonTutorial(self, event):
         """Python tutorial launch event handler"""
 
-        # Doas not work any more
-
         self.main_window.actions.launch_help("Python tutorial",
                                              get_python_tutorial_path())
 
+    def OnDependencies(self, event):
+        """Display dependency dialog"""
+
+        dlg = DependencyDialog(self.main_window)
+        dlg.ShowModal()
+        dlg.Destroy()
+
     def OnAbout(self, event):
         """About dialog event handler"""
 
