@@ -296,17 +296,26 @@ class MainMenu(_filledMenu, EventMixin):
                         wx.ITEM_CHECK]]],
                 [item, [self.EntryLineToggleMsg, _("Entry line"),
                         _("Shows and hides the entry line.")], wx.ITEM_CHECK],
+                [item, [self.TableListToggleMsg, _("Table list"),
+                        _("Shows and hides the table selection list.")],
+                    wx.ITEM_CHECK],
                 ["Separator"],
                 [item, [self.DisplayGotoCellDialogMsg,
                         _("Go to cell") + "\tCtrl+G",
                         _("Moves the grid to a cell."), wx.ID_INDEX]],
                 ["Separator"],
+                [item, [self.SpellCheckMsg, _("Check spelling"),
+                        _("Turn spell checking on and off.")], wx.ITEM_CHECK],
+                ["Separator"],
                 [item, [self.ZoomInMsg, _("Zoom in") + "\tCtrl++",
                         _("Zoom in grid."), wx.ID_ZOOM_IN]],
                 [item, [self.ZoomOutMsg, _("Zoom out") + "\tCtrl+-",
                         _("Zoom out grid."), wx.ID_ZOOM_OUT]],
                 [item, [self.ZoomStandardMsg, _("Normal size") + "\tCtrl+0",
                         _("Show grid in standard zoom."), wx.ID_ZOOM_100]],
+                [item, [self.ZoomFitMsg, _("Zoom to fit") + "\tF6",
+                        _("Zooms the grid to fit the visible window space."),
+                        wx.ID_ZOOM_FIT]],
                 ["Separator"],
                 [item, [self.RefreshSelectionMsg,
                         _("Refresh selected cells") + "\tF5",
@@ -322,6 +331,11 @@ class MainMenu(_filledMenu, EventMixin):
                           "crosshatch.")],
                  wx.ITEM_CHECK]]],
             [wx.Menu, _("F&ormat"), [
+                [item, [self.CopyFormatMsg, _("Copy format") + "\tAlt+Ctrl+C",
+                        _("Copy format of selection to the clipboard")]],
+                [item, [self.PasteFormatMsg, _("Paste format") + "\tAlt+Ctrl+V",
+                        _("Paste format of selection to the clipboard")]],
+                ["Separator"],
                 [item, [self.FontDialogMsg, _("Font..."),
                         _("Launch font dialog.")]],
                 [item, [self.FontBoldMsg, _("Bold") + "\tCtrl+B",
@@ -395,6 +409,9 @@ class MainMenu(_filledMenu, EventMixin):
                 [item, [self.FaqMsg, _("&FAQ"),
                         _("Frequently asked questions")]],
                 ["Separator"],
+                [item, [self.DependenciesMsg, _("Dependencies"),
+                        _("Overview of installed dependencies")]],
+                ["Separator"],
                 [item, [self.AboutMsg, _("&About"), _("About pyspread"),
                         wx.ID_ABOUT]]]]
         ]
