@@ -47,6 +47,7 @@ import src.lib.i18n as i18n
 from src.config import config
 from src.sysvars import get_default_font, get_font_list
 from icons import icons
+from _gui_interfaces import ModalDialogInterfaceMixin
 
 import _widgets
 
@@ -54,7 +55,7 @@ import _widgets
 _ = i18n.language.ugettext
 
 
-class ToolbarBase(aui.AuiToolBar, EventMixin):
+class ToolbarBase(aui.AuiToolBar, EventMixin, ModalDialogInterfaceMixin):
     """Base class for toolbars, requires self.toolbardata set in init
 
     Toolbardata has the following structure:
@@ -166,6 +167,8 @@ class MainToolbar(ToolbarBase):
             ["T", self.UndoMsg, "Undo", _("Undo")],
             ["T", self.RedoMsg, "Redo", _("Redo")],
             ["S"],
+            ["O", "CheckSpelling", _("Check spelling")],
+            ["S"],
             ["T", self.FindFocusMsg, "Find", _("Find")],
             ["T", self.ReplaceMsg, "FindReplace", _("Replace")],
             ["S"],
@@ -183,6 +186,40 @@ class MainToolbar(ToolbarBase):
 
         self.add_tools()
 
+        # Initialize spell checking toggle tool
+        spelltoolid = self.label2id["CheckSpelling"]
+        self.ToggleTool(spelltoolid, config["check_spelling"])
+
+        toggle_id = self.parent.menubar.FindMenuItem(_("View"),
+                                                     _("Check spelling"))
+        if toggle_id != -1:
+            # Check may fail if translation is incomplete
+            toggle_item = self.parent.menubar.FindItemById(toggle_id)
+
+            # Adjust toggle to pane visibility
+            toggle_item.Check(config["check_spelling"])
+
+        # Bindings
+        # --------
+
+        self.Bind(wx.EVT_TOOL, self.OnToggleTool)
+
+    def OnToggleTool(self, event):
+        """Tool event handler"""
+
+        config["check_spelling"] = str(event.IsChecked())
+        toggle_id = self.parent.menubar.FindMenuItem(_("View"),
+                                                     _("Check spelling"))
+        if toggle_id != -1:
+            # Check may fail if translation is incomplete
+            toggle_item = self.parent.menubar.FindItemById(toggle_id)
+            toggle_item.Check(event.IsChecked())
+
+        self.parent.grid.grid_renderer.cell_cache.clear()
+        self.parent.grid.ForceRefresh()
+
+        event.Skip()
+
 # end of class MainToolbar
 
 
@@ -209,6 +246,8 @@ class WidgetToolbar(ToolbarBase):
 
     def __init__(self, parent, *args, **kwargs):
 
+        self.main_window = parent
+
         ToolbarBase.__init__(self, parent, *args, **kwargs)
 
         self.button_cell_button_id = wx.NewId()
@@ -219,6 +258,14 @@ class WidgetToolbar(ToolbarBase):
         self.Bind(wx.EVT_TOOL, self.OnButtonCell,
                   id=self.button_cell_button_id)
 
+        self.video_cell_button_id = wx.NewId()
+        iconname = "VIDEO_CELL"
+        bmp = icons[iconname]
+        self.AddCheckTool(self.video_cell_button_id, iconname, bmp, bmp,
+                          short_help_string=_("Video cell"))
+
+        self.Bind(wx.EVT_TOOL, self.OnVideoCell, id=self.video_cell_button_id)
+
         self.parent.Bind(self.EVT_CMD_TOOLBAR_UPDATE, self.OnUpdate)
 
     def _get_button_label(self):
@@ -247,6 +294,21 @@ class WidgetToolbar(ToolbarBase):
 
         event.Skip()
 
+    def OnVideoCell(self, event):
+        """Event handler for video cell toggle button"""
+
+        if self.video_cell_button_id == event.GetId():
+            if event.IsChecked():
+                wildcard = _("Media files") + " (*.*)|*.*"
+                videofile, __ = self.get_filepath_findex_from_user(
+                    wildcard, "Choose video or audio file", wx.OPEN)
+                post_command_event(self, self.VideoCellMsg,
+                                   videofile=videofile)
+            else:
+                post_command_event(self, self.VideoCellMsg, videofile=False)
+
+        event.Skip()
+
     def OnUpdate(self, event):
         """Updates the toolbar states"""
 
