@@ -37,6 +37,7 @@ Provides:
  10. EntryLine: The line for entering cell code
  11. StatusBar: Main window statusbar
  12. TableChoiceIntCtrl: IntCtrl for choosing the current grid table
+ 13. TableChoiceListCtrl: Virtual ListCtrl for choosing the current grid table
 
 """
 
@@ -55,6 +56,11 @@ import wx.grid
 import wx.combo
 import wx.stc as stc
 from wx.lib.intctrl import IntCtrl, EVT_INT
+import wx.lib.wxcairo
+from wx.lib.mixins.listctrl import ListCtrlAutoWidthMixin
+import cairo
+import pango
+import pangocairo
 
 import src.lib.i18n as i18n
 from src.lib.parsers import common_start
@@ -570,24 +576,32 @@ class FontChoiceCombobox(ImageComboBox):
         if item == wx.NOT_FOUND:
             return
 
-        __rect = wx.Rect(*rect)  # make a copy
-        __rect.Deflate(3, 5)
+        default_font_size = get_default_font().GetPointSize()
 
-        font_string = self.GetString(item)
+        context = wx.lib.wxcairo.ContextFromDC(dc)
 
-        font = get_default_font()
-        font.SetFaceName(font_string)
-        if not is_gtk():
-            # Do not display fonts in font coice box for Windows
-            font.SetFamily(wx.FONTFAMILY_SWISS)
-        dc.SetFont(font)
+        context.rectangle(*rect)
+        context.clip()
 
-        text_width, text_height = dc.GetTextExtent(font_string)
-        text_x = __rect.x
-        text_y = __rect.y + int((__rect.height - text_height) / 2.0)
+        pangocairo_context = pangocairo.CairoContext(context)
+        pangocairo_context.set_antialias(cairo.ANTIALIAS_SUBPIXEL)
 
-        # Draw the example text in the combobox
-        dc.DrawText(font_string, text_x, text_y)
+        layout = pangocairo_context.create_layout()
+        fontname = self.GetString(item)
+        font = pango.FontDescription("{} {}".format(fontname,
+                                                    default_font_size))
+        layout.set_font_description(font)
+
+        layout.set_text(fontname)
+        context.set_source_rgb(0, 0, 0)
+
+        height = layout.get_pixel_extents()[1][3]
+
+        y_adjust = int((rect.height - height) / 2.0)
+        context.translate(rect.x + 3, rect.y + y_adjust)
+
+        pangocairo_context.update_layout(layout)
+        pangocairo_context.show_layout(layout)
 
 # end of class FontChoiceCombobox
 
@@ -1197,6 +1211,7 @@ class TableChoiceIntCtrl(IntCtrl, GridEventMixin, GridActionEventMixin):
 
         # Prevent lost IntCtrl changes
         if self.switching:
+            time.sleep(0.1)
             return
 
         value = self.GetValue()
@@ -1205,9 +1220,9 @@ class TableChoiceIntCtrl(IntCtrl, GridEventMixin, GridActionEventMixin):
         if current_time < self.last_change_s + 0.01:
             return
 
-        if event.GetWheelRotation() > 0:
+        if event.GetWheelRotation() >= event.GetWheelDelta():
             self.SetValue(min(value+1, self.no_tabs-1))
-        else:
+        elif event.GetWheelRotation() <= -event.GetWheelDelta():
             self.SetValue(max(value-1, 0))
 
     def OnShapeChange(self, event):
@@ -1228,3 +1243,174 @@ class TableChoiceIntCtrl(IntCtrl, GridEventMixin, GridActionEventMixin):
         event.Skip()
 
 # end of class TableChoiceIntCtrl
+
+
+class TableChoiceListCtrl(wx.ListCtrl, ListCtrlAutoWidthMixin, GridEventMixin,
+                          GridActionEventMixin):
+    """Virtual ListCtrl for choosing the current grid table"""
+
+    def __init__(self, main_window, grid):
+        style = wx.LC_REPORT | wx.LC_VIRTUAL | wx.LC_NO_HEADER | \
+                wx.LC_SINGLE_SEL
+        wx.ListCtrl.__init__(self, main_window, -1, style=style)
+
+        self.main_window = main_window
+        self.grid = grid
+
+        self.InsertColumn(0, 'Tables')
+
+        shape = grid.code_array.shape
+        self.SetItemCount(shape[2])
+
+        self.setResizeColumn(0)
+        self.Select(0)
+
+        self.main_window.Bind(self.EVT_CMD_RESIZE_GRID, self.OnResizeGrid)
+        self.Bind(wx.EVT_LIST_ITEM_SELECTED, self.OnItemSelected)
+        self.Bind(wx.EVT_SIZE, self.OnSize)
+        self.main_window.Bind(self.EVT_CMD_TABLE_CHANGED, self.OnTableChanged)
+
+        # Drag & Drop events
+#==============================================================================
+#         self.Bind(wx.EVT_LIST_BEGIN_DRAG, self.OnDrag)
+#         self.Bind(wx.EVT_LEFT_UP, self.OnMouseUp)
+#         self.Bind(wx.EVT_LEFT_DOWN, self.OnMouseDown)
+#         self.Bind(wx.EVT_LEAVE_WINDOW, self.OnLeaveWindow)
+#         self.Bind(wx.EVT_ENTER_WINDOW, self.OnEnterWindow)
+#         self.Bind(wx.EVT_LIST_INSERT_ITEM, self.OnInsert)
+#         self.Bind(wx.EVT_LIST_DELETE_ITEM, self.OnDelete)
+#==============================================================================
+
+        # Drag & Drop Variables
+        self.IsInControl = True
+        self.startIndex = -1
+        self.dropIndex = -1
+        self.IsDrag = False
+        self.dragIndex = -1
+
+    def OnGetItemText(self, item, col):
+        return str(item)
+
+    def OnItemSelected(self, event):
+        """Item selection event handler"""
+
+        value = event.m_itemIndex
+        self.startIndex = value
+
+        self.switching = True
+        post_command_event(self, self.GridActionTableSwitchMsg, newtable=value)
+        self.switching = False
+
+        event.Skip()
+
+    def OnResizeGrid(self, event):
+        """Event handler for grid resizing"""
+
+        shape = min(event.shape[2], 2**30)
+        self.SetItemCount(shape)
+        event.Skip()
+
+    def OnSize(self, event):
+        """Event handler for size change"""
+
+        self.resizeColumn(0)
+        event.Skip()
+
+    def OnTableChanged(self, event):
+        """Table changed event handler"""
+
+        if hasattr(event, 'table'):
+            self.Select(event.table)
+            self.EnsureVisible(event.table)
+
+        event.Skip()
+
+    # Drag & Drop event handlers
+
+    def OnLeaveWindow(self, event):
+        self.IsInControl = False
+        self.IsDrag = False
+        event.Skip()
+
+    def OnEnterWindow(self, event):
+        self.IsInControl = True
+        event.Skip()
+
+    def OnDrag(self, event):
+        self.IsDrag = True
+        self.dragIndex = event.m_itemIndex
+        event.Skip()
+
+    def OnMouseUp(self, event):
+        """Generate a dropIndex.
+
+        Process: check self.IsInControl, check self.IsDrag, HitTest,
+                 compare HitTest value
+        The mouse can end up in 5 different places:
+        Outside the Control
+        On itself
+        Above its starting point and on another item
+        Below its starting point and on another item
+        Below its starting point and not on another item
+
+        """
+
+        if not self.IsInControl:  # 1. Outside the control : Do Nothing
+            self.IsDrag = False
+        elif self.IsDrag:
+            if not self.IsDrag:
+                # In control and is a drag event : Determine Location
+                self.hitIndex = self.HitTest(event.GetPosition())
+                self.dropIndex = self.hitIndex[0]
+                # Drop index indicates where the drop location is;
+                # what index number
+
+                # Determine dropIndex and its validity
+
+                # 2. On itself or below control : Do Nothing
+                if not (self.dropIndex == self.startIndex or
+                        self.dropIndex == -1):
+                    # Now that dropIndex has been established do 3 things
+                    # 1. gather item data
+                    # 2. delete item in list
+                    # 3. insert item & it's data into the list at the new index
+                    print self.startIndex, self.dropIndex
+
+                    # dropList is a list of field values from the list control
+                    dropList = []
+
+                    thisItem = self.GetItem(self.startIndex)
+                    for x in xrange(self.GetColumnCount()):
+                        dropList.append(
+                            self.GetItem(self.startIndex, x).GetText())
+                    thisItem.SetId(self.dropIndex)
+                    self.DeleteItem(self.startIndex)
+                    self.InsertItem(thisItem)
+                    for x in range(self.GetColumnCount()):
+                        self.SetStringItem(self.dropIndex, x, dropList[x])
+            # If in control but not a drag event : Do Nothing
+
+        self.IsDrag = False
+        event.Skip()
+
+    def OnMouseDown(self, event):
+        self.IsInControl = True
+        event.Skip()
+
+    def OnInsert(self, event):
+        # Sequencing on a drop event is:
+        # wx.EVT_LIST_ITEM_SELECTED
+        # wx.EVT_LIST_BEGIN_DRAG
+        # wx.EVT_LEFT_UP
+        # wx.EVT_LIST_ITEM_SELECTED (at the new index)
+        # wx.EVT_LIST_INSERT_ITEM
+        # --------------------------------
+        # this call to onStripe catches any addition to the list; drag or not
+
+        self.dragIndex = -1
+        event.Skip()
+
+    def OnDelete(self, event):
+        event.Skip()
+
+# end of class TableChoiceListCtrl
