@@ -55,6 +55,7 @@ from src.lib.typechecks import is_slice_like, is_string_like, is_generator_like
 from src.lib.selection import Selection
 
 import src.lib.charts as charts
+from src.gui.grid_panels import vlcpanel_factory
 
 from src.sysvars import get_color, get_font_string
 
@@ -108,7 +109,7 @@ class CellAttributes(list):
         "strikethrough": False,
         "locked": False,
         "angle": 0.0,
-        "column-width": 150,
+        "column-width": 75,
         "row-height": 26,
         "vertical_align": "top",
         "justification": "left",
@@ -116,11 +117,14 @@ class CellAttributes(list):
         "merge_area": None,
         "markup": False,
         "button_cell": False,
+        "panel_cell": False,
+        "video_volume": None,
     }
 
     # Cache for __getattr__ maps key to tuple of len and attr_dict
 
     _attr_cache = {}
+    _table_cache = {}
 
     def undoable_append(self, value, mark_unredo=True):
         """Appends item to list and provides undo and redo functionality"""
@@ -136,6 +140,8 @@ class CellAttributes(list):
         self.append(value)
         self._attr_cache.clear()
 
+        sel, tab, val = value
+
     def __getitem__(self, key):
         """Returns attribute dict for a single key"""
 
@@ -148,19 +154,48 @@ class CellAttributes(list):
             if cache_len == len(self):
                 return cache_dict
 
+        # Update table cache if it is outdated (e.g. when creating a new grid)
+        if len(self) != self._len_table_cache():
+            self._update_table_cache()
+
         row, col, tab = key
 
         result_dict = copy(self.default_cell_attributes)
 
-        for selection, table, attr_dict in self:
-            if tab == table and (row, col) in selection:
-                result_dict.update(attr_dict)
+        try:
+            for selection, attr_dict in self._table_cache[tab]:
+                if (row, col) in selection:
+                    result_dict.update(attr_dict)
+        except KeyError:
+            pass
 
         # Upddate cache with current length and dict
         self._attr_cache[key] = (len(self), result_dict)
 
         return result_dict
 
+    def _len_table_cache(self):
+        """Returns the length of the table cache"""
+
+        length = 0
+
+        for table in self._table_cache:
+            length += len(self._table_cache[table])
+
+        return length
+
+    def _update_table_cache(self):
+        """Clears and updates the table cache to be in sync with self"""
+
+        self._table_cache.clear()
+        for sel, tab, val in self:
+            try:
+                self._table_cache[tab].append((sel, val))
+            except KeyError:
+                self._table_cache[tab] = [(sel, val)]
+
+        assert len(self) == self._len_table_cache()
+
     def get_merging_cell(self, key):
         """Returns key of cell that merges the cell key
 
@@ -262,6 +297,17 @@ class DataArray(object):
         # Safe mode
         self.safe_mode = False
 
+    def __eq__(self, other):
+        if not hasattr(other, "dict_grid") or \
+           not hasattr(other, "cell_attributes"):
+            return NotImplemented
+
+        return self.dict_grid == other.dict_grid and \
+            self.cell_attributes == other.cell_attributes
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     # Data is the central content interface for loading / saving data.
     # It shall be used for loading and saving from and to pys and other files.
     # It shall be used for loading and saving macros.
@@ -644,7 +690,7 @@ class DataArray(object):
             else:
                 # Value is empty --> delete cell
                 try:
-                    self.dict_grid.pop(key)
+                    self.pop(key)
 
                 except (KeyError, TypeError):
                     pass
@@ -878,6 +924,7 @@ class DataArray(object):
                 self.cell_attributes.pop(i)
 
         self.cell_attributes._attr_cache.clear()
+        self.cell_attributes._update_table_cache()
 
         undo_operation = (self._adjust_cell_attributes,
                           [insertion_point, -no_to_insert, axis, tab,
@@ -1074,6 +1121,9 @@ class CodeArray(DataArray):
     # Cache for frozen objects
     frozen_cache = {}
 
+    # Custom font storage
+    custom_fonts = {}
+
     def __setitem__(self, key, value, mark_unredo=True):
         """Sets cell code and resets result cache"""
 
@@ -1194,7 +1244,8 @@ class CodeArray(DataArray):
 
         env_dict = {'X': key[0], 'Y': key[1], 'Z': key[2], 'bz2': bz2,
                     'base64': base64, 'charts': charts, 'nn': nn,
-                    'R': key[0], 'C': key[1], 'T': key[2], 'S': self}
+                    'R': key[0], 'C': key[1], 'T': key[2], 'S': self,
+                    'vlcpanel_factory': vlcpanel_factory}
         env = self._get_updated_environment(env_dict=env_dict)
 
         _old_code = self(key)
@@ -1310,6 +1361,7 @@ class CodeArray(DataArray):
         """Reloads modules that are available in cells"""
 
         import src.lib.charts as charts
+        from src.gui.grid_panels import vlcpanel_factory
         modules = [charts, bz2, base64, re, ast, sys, wx, numpy, datetime]
 
         for module in modules:
@@ -1324,7 +1376,8 @@ class CodeArray(DataArray):
                      'CellAttributes', 'product', 'ast', '__builtins__',
                      '__file__', 'charts', 'sys', 'is_slice_like', '__name__',
                      'copy', 'imap', 'wx', 'ifilter', 'Selection', 'DictGrid',
-                     'numpy', 'CodeArray', 'DataArray', 'datetime']
+                     'numpy', 'CodeArray', 'DataArray', 'datetime',
+                     'vlcpanel_factory']
 
         for key in globals().keys():
             if key not in base_keys:
